==> ikaaro-0.50.2.tar.gz: ikaaro-0.50.2/ui/tiny_mce/plugins/media/langs/fr_dlg.js <==
tinyMCE.addI18n('fr.media_dlg',{
title:"Ins\u00E9rer/\u00C9diter un fichier m\u00E9dia",
general:"G\u00E9n\u00E9ral",
advanced:"Avanc\u00E9",
file:"Fichier / URL",
list:"Liste",
size:"Dimensions",
preview:"Pr\u00E9visualiser",
constrain_proportions:"Conserver les proportions",
type:"Type",
id:"Id",
name:"Nom",
class_name:"Classe",
vspace:"Espacement vertical",
hspace:"Espacement horizontal",
play:"Lecture automatique",
loop:"Lire en boucle",
menu:"Afficher le menu",
quality:"Qualit\u00E9",
scale:"\u00C9chelle",
align:"Alignement",
salign:"SAlign",
wmode:"WMode",
bgcolor:"Fond",
base:"Base",
flashvars:"Variables flash",
liveconnect:"SWLiveConnect",
autohref:"AutoHREF",
cache:"Cache",
hidden:"Cach\u00E9",
controller:"Controlleur",
kioskmode:"Mode kiosque",
playeveryframe:"Jouer toutes les images",
targetcache:"Cache cible",
correction:"Pas de correction",
enablejavascript:"Activer le JavaScript",
starttime:"Temps de d\u00E9but",
endtime:"Temps de fin",
href:"Href",
qtsrcchokespeed:"Choke speed",
target:"Cible",
volume:"Volume",
autostart:"Lire automatiquement",
enabled:"Activ\u00E9",
fullscreen:"Plein \u00E9cran",
invokeurls:"Invoquer URLs",
mute:"Silence",
stretchtofit:"\u00C9tendre pour adapter la taille",
windowlessvideo:"Vid\u00E9o sans fen\u00EAtre",
balance:"Balance",
baseurl:"Adresse de base",
captioningid:"Captioning id",
currentmarker:"Marqueur actuel",
currentposition:"Position actuelle",
defaultframe:"Image par d\u00E9faut",
playcount:"Compteur",
rate:"Taux",
uimode:"Mode UI",
flash_options:"Options Flash",
qt_options:"Options Quicktime",
wmp_options:"Windows media player options",
rmp_options:"Options Real media player",
shockwave_options:"Options Shockwave",
autogotourl:"Aller automatiquement \u00E0 l'URL",
center:"Centrer",
imagestatus:"Statut de l'image",
maintainaspect:"Maintenir l'aspect",
nojava:"Pas java",
prefetch:"Prefetch",
shuffle:"Al\u00E9atoire",
console:"Console",
numloop:"Nombre de tours",
controls:"Contr\u00F4les",
scriptcallbacks:"Callback de script",
swstretchstyle:"Stretch style",
swstretchhalign:"Stretch horizontal",
swstretchvalign:"Stretch vertical",
sound:"Son",
progress:"Progr\u00E8s",
qtsrc:"QT Src",
qt_stream_warn:"Les ressources stream\u00E9es rtsp doivent \u00EAtre ajout\u00E9es au champs QT Src dans l'onglet avanc\u00E9.\nVous devriez aussi ajouter une version non stream\u00E9e au QT src.",
align_top:"Haut",
align_right:"Droit",
align_bottom:"Bas",
align_left:"Gauche",
align_center:"Centr\u00E9",
align_top_left:"Haut gauche",
align_top_right:"haut droit",
align_bottom_left:"Bas gauche",
align_bottom_right:"Bas droite",
flv_options:"Options de la vid\u00E9o Flash",
flv_scalemode:"Mode \u00E0 l'\u00E9chelle",
flv_buffer:"Tampon",
flv_startimage:"Image de d\u00E9but",
flv_starttime:"Temps au d\u00E9but",
flv_defaultvolume:"Volume par d\u00E9faut",
flv_hiddengui:"Interface utilisateur cach\u00E9e",
flv_autostart:"D\u00E9marage automatique",
flv_loop:"En boucle",
flv_showscalemodes:"Montrer les diff\u00E9rentes \u00E9chelles",
flv_smoothvideo:"Vid\u00E9o adoucie",
flv_jscallback:"Callback JavaScript"
});

==> ikaaro-0.61.4.tar.gz: ikaaro-0.61.4/ui/tiny_mce/plugins/media/langs/fr_dlg.js <==
tinyMCE.addI18n('fr.media_dlg',{
title:"Ins\u00E9rer / \u00E9diter un fichier m\u00E9dia",
general:"G\u00E9n\u00E9ral",
advanced:"Avanc\u00E9",
file:"Fichier / URL",
list:"Liste",
size:"Dimensions",
preview:"Pr\u00E9visualisation",
constrain_proportions:"Conserver les proportions",
type:"Type",
id:"Id",
name:"Nom",
class_name:"Classe",
vspace:"Espacement vertical",
hspace:"Espacement horizontal",
play:"Lecture automatique",
loop:"Lire en boucle",
menu:"Afficher le menu",
quality:"Qualit\u00E9",
scale:"\u00C9chelle",
align:"Alignement",
salign:"SAlign",
wmode:"WMode",
bgcolor:"Fond",
base:"Base",
flashvars:"Variables flash",
liveconnect:"SWLiveConnect",
autohref:"AutoHREF",
cache:"Cache",
hidden:"Cach\u00E9",
controller:"Contr\u00F4leur",
kioskmode:"Mode kiosque",
playeveryframe:"Jouer toutes les images",
targetcache:"Cache cible",
correction:"Pas de correction",
enablejavascript:"Activer le JavaScript",
starttime:"D\u00E9but",
endtime:"Fin",
href:"Href",
qtsrcchokespeed:"D\u00E9bit maximum",
target:"Cible",
volume:"Volume",
autostart:"Lire automatiquement",
enabled:"Activ\u00E9",
fullscreen:"Plein \u00E9cran",
invokeurls:"Invoquer URLs",
mute:"Muet",
stretchtofit:"\u00C9tendre pour adapter la taille",
windowlessvideo:"Vid\u00E9o sans fen\u00EAtre",
balance:"Balance",
baseurl:"Adresse de base",
captioningid:"Captioning id",
currentmarker:"Marqueur actuel",
currentposition:"Position actuelle",
defaultframe:"Image par d\u00E9faut",
playcount:"Compteur",
rate:"Taux",
uimode:"Mode UI",
flash_options:"Options Flash",
qt_options:"Options Quicktime",
wmp_options:"Windows media player options",
rmp_options:"Options Real media player",
shockwave_options:"Options Shockwave",
autogotourl:"Aller automatiquement \u00E0 l'URL",
center:"Centrer",
imagestatus:"Statut de l'image",
maintainaspect:"Maintenir l'aspect",
nojava:"Pas java",
prefetch:"Pr\u00E9chargement",
shuffle:"Al\u00E9atoire",
console:"Console",
numloop:"Nombre de tours",
controls:"Contr\u00F4les",
scriptcallbacks:"Callback de script",
swstretchstyle:"Stretch style",
swstretchhalign:"Stretch horizontal",
swstretchvalign:"Stretch vertical",
sound:"Son",
progress:"Progression",
qtsrc:"Source QT",
qt_stream_warn:"Les ressources rtsp en streaming doivent \u00EAtre ajout\u00E9es au champ \u00AB Source QT \u00BB dans l'onglet avanc\u00E9.\nVous devriez aussi ajouter une version n'\u00E9tant pas en streaming au champ \u00AB source QT \u00BB.",
align_top:"Haut",
align_right:"Droite",
align_bottom:"Bas",
align_left:"Gauche",
align_center:"Centr\u00E9",
align_top_left:"En haut \u00E0 gauche",
align_top_right:"En haut \u00E0 droite",
align_bottom_left:"En bas \u00E0 gauche",
align_bottom_right:"En bas \u00E0 droite",
flv_options:"Options de la vid\u00E9o Flash",
flv_scalemode:"\u00C9chelle",
flv_buffer:"Tampon",
flv_startimage:"Image de d\u00E9marrage",
flv_starttime:"Temps au d\u00E9but",
flv_defaultvolume:"Volume par d\u00E9faut",
flv_hiddengui:"Interface utilisateur cach\u00E9e",
flv_autostart:"D\u00E9marrage automatique",
flv_loop:"En boucle",
flv_showscalemodes:"Montrer les diff\u00E9rentes \u00E9chelles",
flv_smoothvideo:"Vid\u00E9o adoucie",
flv_jscallback:"Callback JavaScript"
});
